# AVT

[![PyPI version](https://badge.fury.io/py/avt.svg)](https://badge.fury.io/py/avt)

AVT, or the "Automated Version Tester" is a tool to bring reproducibility to software
that didn't originally had it. We use a grid estimation approach to sniff software files, 
and test building across a variety of environments and versions to determine one or
more optimal build environments.

**under development**

## License

 * Free software: MPL 2.0 License
